/*----------------------------------
This file generates the estimates in
table XXX related to property rights using the ATS
-----------------------------------*/

/*----------------------------------------------
Part I: Getting Household Data & Chiefdom Data
------------------------------------------------*/

loc run = 1
if `run' == 1{
  
/*Getting Household Head Education Level*/
use $SL_data/ATS/AHTS_HH_B1_HH_ROSTER.dta, clear

gen primary = inlist(b1e,16,17,21,22,23,24,25,26,31,32,33,34,35,36)==1

gen age = 0
replace age = b1b if b1d==1

gen female = 0
replace female = 1 if (b1d==1 & b1c==2)

gen primary_max = primary
gen primary_head = primary
   replace primary_head = 0 if b1d!=1
   replace primary_head = . if b1e>=. & b1d==1

collapse (max) primary_max primary_head age female, by(serial_num)

gen age2 = age^2

sort serial_num
tempfile ed
save `ed'

/*Household Head Ethnicity, Stranger Status, and Chiefdom*/
use $SL_data/ATS/AHTS_HH_SINGLE.dta, clear

gen ethnicity = b5
*recode ethnicity ( /*12 13 14 15 16*/ 17 18 19 20 = 66 )

gen mende = (b5==2)
gen temne = (b5==3)

gen stranger = (b9==2)
replace stranger = . if b9>=.

keep serial_num ethnicity stranger mende temne
sort serial_num

/*Bringing in Education from Above*/
merge 1:1 serial_num using `ed'
drop _m

/*Bringing in Chiefdom & District Codes (confidential, from Tavneet)*/
merge 1:1 serial_num using  $SL_data/ATS/key_Tristan.dta
drop _m

rename chiefdom_code chiefcode

/*Bringing in Chief Data*/

loc exocontrol mitchell_km coast_dist rail_dist river_dist dist_min mining_1930

  
preserve
use $SL_data/chiefs_survey_clean_out.dta, clear
keep chiefcode amalgamation n_chiefs fam_num_ln district fam_cat research_dummy* `exocontrol'
sort chiefcode
tempfile chiefs
save `chiefs'
restore

sort chiefcode
merge m:1 chiefcode using `chiefs'
keep if _m==3
drop _m

compare district district_code

save $SL_temp/ats_hh.dta, replace

}
/*------------------------------------------
PART II: Getting Farm Characteristics
----------------------------------------*/

loc run = 1
if `run' == 1{
  
use $SL_data/ATS/AHTS_HH_D2_FARM_CHARACTERISTICS.dta, clear
  
gen ecology = d2a


/*Looking at acres. Issue here is that many farms, particularly those that produce rice,
measure farm size in bushels of seed. This is not ideal, as the measure may
be correlated with actual size and productivity. Such measures, however, are common in agricultural surveys in developing countries*/
gen acres = d2d_qty

gen bushel_unit = (d2d_unit==2)
mean bushel_unit [pw=weight_ATS_hh]

/*(Converting Bushels to Acres using 1:1 seeding rate as reccomended by Tavneet)*/
replace acres = acres*0.000247105 if d2d_unit==3
replace acres = acres*0.000206612 if d2d_unit==4
replace acres = acres*2.47105 if d2d_unit==5

gen rice = (d2b_crop1==1 | d2b_crop2==1 | d2b_crop3==1)
gen maize =  (d2b_crop1==2 | d2b_crop2==2 | d2b_crop3==2)
gen cassava =  (d2b_crop1==6 | d2b_crop2==6 | d2b_crop3==6)
gen sweetpotato =  (d2b_crop1==7 | d2b_crop2==7 | d2b_crop3==7)
gen groundnut =  (d2b_crop1==12 | d2b_crop2==12 | d2b_crop3==12)
gen coffee =  (d2b_crop1==50 | d2b_crop2==50 | d2b_crop3==50)
gen cacao = (d2b_crop1==51 | d2b_crop2==51 | d2b_crop3==51)
gen oilpalm = (d2b_crop1==52 | d2b_crop2==52 | d2b_crop3==52)

gen maincrop = (rice == 1| maize==1 | cassava==1 | sweetpotato==1| groundnut==1|coffee ==1| cacao == 1| oilpalm == 1)
gen treecrop = (coffee ==1| cacao == 1| oilpalm == 1)

/*Saving For Use in Ownership Analysis*/
egen tag = tag(serial_num farm_id)
bys serial_num: egen mint = min(tag)
drop if mint==0
  
sort serial_num farm_id
tempfile farms
save $SL_temp/ats_farms.dta, replace


/*------------------------------------------
PART III: Ownership
----------------------------------------*/

loc run = 1
if `run'==1{
  
use $SL_data/ATS/AHTS_HH_D3_FARM_OWNERSHIP.dta, clear

/*Rights to Sell*/
gen sell = (d3b==1)
replace sell = .  if inlist(d3b,1,2)==0

/*Asked Chief for Permission*/
gen chiefask = (d3d ==2)

 egen tag = tag(serial_num farm_id)
bys serial_num: egen mint = min(tag)
drop if mint==0

sort serial_num farm_id
merge 1:1 serial_num farm_id using $SL_temp/ats_farms.dta
keep if _m==3
drop _m

gen upland = (ecology==1)

merge m:1 serial_num using $SL_temp/ats_hh.dta
keep if _m==3

tabstat sell, by(district)
tabstat chiefask, by(district)

loc dec = 3


loc run = 0
if `run' == 1{


/*Summary Stats for Table 1*/
  foreach y of varlist chiefask sell stranger{
    mean `y' [fw = round(weight_ATS_hh) ] if rice==1 & d2c==1
    sum `y' if rice==1 & d2c==1
  tabstat `y' [fw = round(weight_ATS_hh) ] if rice==1 & d2c==1, by(fam_cat) stat(mean sd)
  }

/*Regressions*/
xi: regress chiefask i.stranger fam_num_ln n_chiefs amalgamation female age age2 i.ethnicity i.district_code i.ecology  [pw = weight_ATS_hh] if rice==1 & d2c==1, cluster(chiefcode)

outreg2 using "$SL_out/chiefs_table_ats.tex", replace tex(frag) drop(female age age2 _Iethnicity* _Idistrict* _Iecology* ) dec(`dec')  ctitle("`y'") nonotes noaster  nocons  sortvar(fam_num_ln `elite')  addtext(District Fixed Effects, YES, Ecology Fixed Effects, YES, Historical Controls, NO )

xi: regress chiefask i.stranger*fam_num_ln n_chiefs amalgamation female age age2 i.ethnicity i.district_code i.ecology  [pw = weight_ATS_hh] if rice==1 & d2c==1, cluster(chiefcode)

outreg2 using "$SL_out/chiefs_table_ats.tex", tex(frag) drop(female age age2 _Iethnicity* _Idistrict* _Iecology* ) dec(`dec')  ctitle("`y'") nonotes noaster  nocons  sortvar(fam_num_ln `elite')  addtext(District Fixed Effects, YES, Ecology Fixed Effects, YES, Historical Controls, NO )

xi: regress sell i.stranger fam_num_ln n_chiefs amalgamation female age age2 i.ethnicity i.district_code i.ecology  [pw = weight_ATS_hh] if rice==1 & d2c==1, cluster(chiefcode)

outreg2 using "$SL_out/chiefs_table_ats.tex",  tex(frag) drop(female age age2 _Iethnicity* _Idistrict* _Iecology* ) dec(`dec')  ctitle("`y'") nonotes noaster  nocons  sortvar(fam_num_ln `elite')  addtext(District Fixed Effects, YES, Ecology Fixed Effects, YES, Historical Controls, NO )

xi: regress sell i.stranger*fam_num_ln n_chiefs amalgamation female age age2 i.ethnicity i.district_code i.ecology  [pw = weight_ATS_hh] if rice==1 & d2c==1, cluster(chiefcode)

outreg2 using "$SL_out/chiefs_table_ats.tex",  tex(frag) drop(female age age2 _Iethnicity* _Idistrict* _Iecology* ) dec(`dec')  ctitle("`y'") nonotes noaster  nocons  sortvar(fam_num_ln `elite')  addtext(District Fixed Effects, YES, Ecology Fixed Effects, YES, Historical Controls, NO )



/*Regressions with controls */
xi: regress chiefask i.stranger fam_num_ln n_chiefs amalgamation female age age2 i.ethnicity i.district_code i.ecology `exocontrol'  [pw = weight_ATS_hh] if rice==1 & d2c==1, cluster(chiefcode)

outreg2 using "$SL_out/chiefs_table_ats_exocontrol.tex", replace tex(frag) drop(female age age2 _Iethnicity* _Idistrict* _Iecology* ) dec(`dec')  ctitle("`y'") nonotes noaster  nocons  sortvar(fam_num_ln `elite')  addtext(District Fixed Effects, YES, Ecology Fixed Effects, YES, Historical Controls, YES )

xi: regress chiefask i.stranger*fam_num_ln n_chiefs amalgamation female age age2 i.ethnicity i.district_code i.ecology `exocontrol'  [pw = weight_ATS_hh] if rice==1 & d2c==1, cluster(chiefcode)

outreg2 using "$SL_out/chiefs_table_ats_exocontrol.tex", tex(frag) drop(female age age2 _Iethnicity* _Idistrict* _Iecology* ) dec(`dec')  ctitle("`y'") nonotes noaster  nocons  sortvar(fam_num_ln `elite')  addtext(District Fixed Effects, YES, Ecology Fixed Effects, YES, Historical Controls,YES )

xi: regress sell i.stranger fam_num_ln n_chiefs amalgamation female age age2 i.ethnicity i.district_code i.ecology `exocontrol'  [pw = weight_ATS_hh] if rice==1 & d2c==1, cluster(chiefcode)

outreg2 using "$SL_out/chiefs_table_ats_exocontrol.tex",  tex(frag) drop(female age age2 _Iethnicity* _Idistrict* _Iecology* ) dec(`dec')  ctitle("`y'") nonotes noaster  nocons  sortvar(fam_num_ln `elite')  addtext(District Fixed Effects, YES, Ecology Fixed Effects, YES, Historical Controls, YES )

xi: regress sell i.stranger*fam_num_ln n_chiefs amalgamation female age age2 i.ethnicity i.district_code i.ecology `exocontrol'   [pw = weight_ATS_hh] if rice==1 & d2c==1, cluster(chiefcode)

outreg2 using "$SL_out/chiefs_table_ats_exocontrol.tex",  tex(frag) drop(female age age2 _Iethnicity* _Idistrict* _Iecology* ) dec(`dec')  ctitle("`y'") nonotes noaster  nocons  sortvar(fam_num_ln `elite')  addtext(District Fixed Effects, YES, Ecology Fixed Effects, YES, Historical Controls, YES)


}

/*-------------------------------
Appendix Table: Ecology.
----------------------------*/

/*Probability that a plot owned by a household has lowland rice*/
lab var n_chiefs "Number of chiefs recalled"
lab var amalgamation "Amalgamation"

gen lowland = 1-upland
sum lowland if  rice==1, d

loc mean = round( r(mean), 0.001)
loc sd = round( r(sd), 0.001)
  
xi: regress lowland fam_num_ln  amalgamation n_chiefs i.district_code [pw = weight_ATS_hh] if rice==1 , cluster(chiefcode)

outreg2 fam_num_ln n_chiefs amalgamation  using "$SL_out/chiefs_table_ats_appendix.tex", replace tex(frag) dec(`dec')  ctitle("Lowland Plot") nonotes noaster  nocons  addtext(District Fixed Effects, YES, Outcome mean, `mean', Outcome s.d., `sd' )

/*Looking at chiefdom level share of land that is lowland*/
gen acres_low = lowland*acres

keep if rice==1 
collapse (sum) acres acres_low [pw = weight_ATS_hh], by(chiefcode fam_num_ln n_chiefs amalgamation district_code)

gen lowshr = acres_low/acres
sum lowshr , d

loc mean = round( r(mean), 0.001)
loc sd = round( r(sd), 0.001)

xi: regress lowshr fam_num_ln  amalgamation n_chiefs i.district_code , cluster(chiefcode)

outreg2 fam_num_ln n_chiefs amalgamation  using "$SL_out/chiefs_table_ats_appendix.tex", tex(frag) dec(`dec')  ctitle("Lowland Share") nonotes noaster  nocons  addtext(District Fixed Effects, YES, Outcome mean, `mean', Outcome s.d., `sd' )
